##  Monitor Data Completeness
You can use the Obsolescence: Missing Data Percentage view in reports to get an overview of fact sheets lacking lifecycle information. The missing data percentage view analyzes applications lacking lifecycle information, displaying the percentage of IT components supporting each application without such data.
  * In the Application Landscape report, apply the Obsolescence: Missing Data Percentage view to identifying applications that lack needed information critical for risk evaluation. From the report Settings, cluster the applications by Business Criticality and explore further to identify your mission-critical IT components and link them to catalog items.
![Obsolescence: Missing Data Percentage view in Application Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275294df7a441014b3d0f357cacd7b59_LowRes.gif)
Obsolescence: Missing Data Percentage view in Application Landscape Report
  * Technology Risk and Compliance provides a dedicated obsolescence risk management dashboard. In the dashboard, the Data Completeness panel provides you with a good summary of missing data. Clicking on any of the KPIs takes you to the inventory, where you can manage the process of data completion.
![Data Completeness Panel of Obsolescence Risk Management Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274be1827a441014baebfae6537ad20b_LowRes.png)
Data Completeness Panel of Obsolescence Risk Management Dashboard
